'use strict';
/**
 * @file app.js
 *
 * @brief
 * JSONEditor is an editor to display and edit JSON data in a treeview.
 *
 * Supported browsers: Chrome, Firefox, Safari, Opera, Internet Explorer 8+
 *
 * @license
 * This json editor is open sourced with the intention to use the editor as
 * a component in your own application. Not to just copy and monetize the editor
 * as it is.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy
 * of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 *
 * Copyright (C) 2011-2012 Jos de Jong, http://jsoneditoronline.org
 *
 * @author  Jos de Jong, <wjosdejong@gmail.com>
 * @date    2012-11-03
 */
var editor = null;
var formatter = null;

var app = {};

/**
 * Get the JSON from the formatter and load it in the editor
 */
app.formatterToEditor = function () {
	try {
		editor.set(formatter.get());
	} catch (err) {
		app.notify.showError(err);
	}
};

/**
 * Get the JSON from the editor and load it into the formatter
 */
app.editorToFormatter = function () {
	try {
		formatter.set(editor.get());
	} catch (err) {
		app.notify.showError(err);
	}
};

/**
 * Load the interface (editor, formatter, splitter)
 */
// TODO: split the method load in multiple methods, it is too large
app.load = function (type) {
	try {
		// notification handler
		app.notify = new Notify();

		// default json document
		//var json = {"名字":"消费账户设置","现金账户可消费":{"游戏":1,"商品":1},"赠送账户可消费":{"游戏":1,"商品":0},"赠送账户金额":10};
		var json = "";
        $.post('/settings/getJsonFromFile', {type: type}, function (data) {

			if(data.err != null){

			}else{
				if(data.data.length > 0){
					var raw = data.data[0].value;
					json = JSON.parse(raw);//{"名字":"消费账户设置","现金账户可消费":{"游戏":1,"商品":1},"赠送账户可消费":{"游戏":1,"商品":0},"赠送账户金额":10};
					console.log(json);
					// Store whether editor or formatter is last changed
					app.lastChanged = undefined;

					// formatter
					var container = document.getElementById("jsonformatter");
					formatter = new JSONFormatter(container, {
						change: function () {
							app.lastChanged = formatter;
						}
					});
					formatter.set(json);
					formatter.onError = function (err) {
						app.notify.showError(err);
					};

					// editor
					container = document.getElementById("jsoneditor");
					editor = new JSONEditor(container, {
						change: function () {
							app.lastChanged = editor;
						}
					});
					editor.set(json);
					// TODO: automatically synchronize data of formatter and editor? (editor should keep its state though)

					// splitter
					var domSplitter = document.getElementById('splitter');
					app.splitter = new Splitter({
						container: domSplitter,
						change: function () {
							app.resize();
						}
					});

					// button Formatter-to-Editor
					domSplitter.appendChild(document.createElement('br'));
					domSplitter.appendChild(document.createElement('br'));
					domSplitter.appendChild(document.createElement('br'));
					var toForm = document.createElement('button');
					toForm.id = 'toForm';
					toForm.title = '解析JSON';
					toForm.className = 'convert';
					//toForm.innerHTML = '<div class="convert-right"></div>';
					toForm.innerHTML = '<div>重置</div>';
					toForm.onclick = function () {
						this.focus();
						app.formatterToEditor();
					};
					domSplitter.appendChild(toForm);

					// button Editor-to-Formatter
					domSplitter.appendChild(document.createElement('br'));
					domSplitter.appendChild(document.createElement('br'));
					var toJSON = document.createElement('button');
					toJSON.id = 'toJSON';
					toJSON.title = '保存JSON';
					toJSON.className = 'convert';
					//toJSON.innerHTML = '<div class="convert-left"></div>';
					toJSON.innerHTML = '<div>保存</div>';
					toJSON.onclick = function () {
						this.focus();
						app.editorToFormatter();
						var temp = editor.get();
						var dataString = JSON.stringify(temp);
                        $.post('settings/setJsonToFile', {type: type, dataString: dataString}, function (err) {
							var toShow = new Object();
							toShow.type = "notification";
							toShow.closeButton = "false";

							if(!err.err){
								toShow.message = "保存成功";
								app.notify.showMessage(toShow);
							}else{
								toShow.message = "保存失败";
								app.notify.showMessage(toShow);
							}

						});
					};
					domSplitter.appendChild(toJSON);

					// web page resize handler
					JSONEditor.Events.addEventListener(window, 'resize', app.resize);

					// enforce FireFox to not do spell checking on any input field
					document.body.spellcheck = false;


				}
			}
		});


	} catch (err) {
		app.notify.showError(err);
	}
};

/**
 * Callback method called when a file or url is opened.
 * @param {Error} err
 * @param {String} data
 */
app.openCallback = function (err, data) {
	if (!err) {
		if (data != undefined) {
			formatter.setText(data);
			try {
				var json = JSONEditor.parse(data);
				editor.set(json);
			} catch (err) {
				editor.set({});
				app.notify.showError(err);
			}
		}
	} else {
		app.notify.showError(err);
	}
};



app.resize = function () {
	var domEditor = document.getElementById('jsoneditor');
	var domFormatter = document.getElementById('jsonformatter');
	var domSplitter = document.getElementById('splitter');

	var width = window.innerWidth || document.body.offsetWidth || document.documentElement.offsetWidth;
	var height = window.innerHeight || document.body.offsetHeight || document.documentElement.offsetHeight;
	height = height - 88;
	var splitterWidth = domSplitter.clientWidth;

	var splitterLeft = width * app.splitter.getValue();

	// resize formatter
	domFormatter.style.width = Math.round(splitterLeft) + 'px';

	// resize editor
	// the width has a -1 to prevent the width from being just half a pixel
	// wider than the window, causing the content elements to wrap...
	domEditor.style.left = Math.round(splitterLeft + splitterWidth) + 'px';
	domEditor.style.width = Math.round(width - splitterLeft - splitterWidth - 1) + 'px';
};